@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ * 2007, 2008, 2009 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -260,7 +260,6 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
 {
     int rf, ff;
     int i, j, d, s, fs, rs, rt, ft, m;
-    int promoRank = gameInfo.variant == VariantMakruk ? 3 : 1;
 
     for (rf = 0; rf < BOARD_HEIGHT; rf++) 
       for (ff = BOARD_LEFT; ff < BOARD_RGHT; ff++) {
@@ -304,7 +303,7 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
               }
               if (rf < BOARD_HEIGHT-1 && board[rf + 1][ff] == EmptySquare) {
 		  callback(board, flags,
-			   rf >= BOARD_HEIGHT-1-promoRank ? WhitePromotionQueen : NormalMove,
+			   rf == BOARD_HEIGHT-2 ? WhitePromotionQueen : NormalMove,
 			   rf, ff, rf + 1, ff, closure);
 	      }
 	      if (rf == 1 && board[2][ff] == EmptySquare &&
@@ -319,7 +318,7 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
 		      ((flags & F_KRIEGSPIEL_CAPTURE) ||
 		       BlackPiece(board[rf + 1][ff + s]))) {
 		      callback(board, flags, 
-			       rf >= BOARD_HEIGHT-1-promoRank ? WhitePromotionQueen : NormalMove,
+			       rf == BOARD_HEIGHT-2 ? WhitePromotionQueen : NormalMove,
 			       rf, ff, rf + 1, ff + s, closure);
 		  }
 		  if (rf == BOARD_HEIGHT-4) {
@@ -354,7 +353,7 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
               }
 	      if (rf > 0 && board[rf - 1][ff] == EmptySquare) {
 		  callback(board, flags, 
-			   rf <= promoRank ? BlackPromotionQueen : NormalMove,
+			   rf == 1 ? BlackPromotionQueen : NormalMove,
 			   rf, ff, rf - 1, ff, closure);
 	      }
 	      if (rf == BOARD_HEIGHT-2 && board[BOARD_HEIGHT-3][ff] == EmptySquare &&
@@ -369,7 +368,7 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
 		      ((flags & F_KRIEGSPIEL_CAPTURE) ||
 		       WhitePiece(board[rf - 1][ff + s]))) {
 		      callback(board, flags, 
-			       rf <= promoRank ? BlackPromotionQueen : NormalMove,
+			       rf == 1 ? BlackPromotionQueen : NormalMove,
 			       rf, ff, rf - 1, ff + s, closure);
 		  }
 		  if (rf == 3) {
@@ -609,8 +608,6 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
 
             /* Shogi Pawn and Silver General: first the Pawn move,    */
             /* then the General continues like a Ferz                 */
-            case WhiteMan:
-                if(gameInfo.variant != VariantMakruk) goto commoner;
             case SHOGI WhitePawn:
             case SHOGI WhiteFerz:
                   if (rf < BOARD_HEIGHT-1 &&
@@ -620,8 +617,6 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
               if(piece != SHOGI WhitePawn) goto finishSilver;
               break;
 
-            case BlackMan:
-                if(gameInfo.variant != VariantMakruk) goto commoner;
             case SHOGI BlackPawn:
             case SHOGI BlackFerz:
                   if (rf > 0 &&
@@ -649,7 +644,8 @@ void GenPseudoLegal(board, flags, epfile, callback, closure)
 	    case WhiteSilver:
 	    case BlackSilver:
 		m++; // [HGM] superchess: use for Centaur
-            commoner:
+            case WhiteMan:
+            case BlackMan:
             case SHOGI WhiteKing:
             case SHOGI BlackKing:
 	    case WhiteKing:
@@ -756,7 +752,7 @@ int GenLegal(board, flags, epfile, castlingRights, callback, closure)
      Board board;
      int flags;
      int epfile;
-     signed char castlingRights[];
+     char castlingRights[];
      MoveCallback callback;
      VOIDSTAR closure;
 {
@@ -1044,7 +1040,7 @@ ChessMove LegalityTest(board, flags, epfile, castlingRights, rf, ff, rt, ft, pro
      Board board;
      int flags, epfile;
      int rf, ff, rt, ft, promoChar;
-     signed char castlingRights[];
+     char castlingRights[];
 {
     LegalityTestClosure cl; ChessSquare piece = board[rf][ff];
     
@@ -1137,7 +1133,7 @@ void MateTestCallback(board, flags, kind, rf, ff, rt, ft, closure)
 int MateTest(board, flags, epfile, castlingRights)
      Board board;
      int flags, epfile;
-     signed char castlingRights[];
+     char castlingRights[];
 {
     MateTestClosure cl;
     int inCheck, r, f, myPieces=0, hisPieces=0, nrKing=0;
